@@ -8,7 +8,7 @@ from .api_handler import APIHandler
 from .account import Account
 from .user import User
 
-__version__ = "1.0.10"
+__version__ = "1.0.11"
 
 
 class FreedomClient(object):
@@ -34,23 +34,31 @@ class FreedomClient(object):
         )
         assert self.api is not None
 
-    def get_account(self, account_id):
+    def get_account(self, account_id, params=None):
         """:obj:`Account`: Fetch an account by its account ID (Axxxxxxxxxxxx).
 
         Args:
             account_id (str): Account ID.
+            params (dict): Optional query parameters.
         """
 
-        account_data = self.api.call("GET", "/accounts/{}".format(account_id))
+        account_data = self.api.call(
+            "GET",
+            "/accounts/{}".format(account_id),
+            params=params,
+        )
         if not account_data:
             return None
         return Account(account_data["account"], account_data, api=self.api)
 
-    def get_accounts(self):
+    def get_accounts(self, params=None):
         """:obj:`list` of :obj:`Account`: Fetch a list of all accounts that are visible/accessible.
+
+        Args:
+            params (dict): Optional query parameters.
         """
 
-        result = self.api.call("GET", "/accounts")
+        result = self.api.call("GET", "/accounts", params=params)
         if not result:
             return []
         return [
@@ -58,23 +66,38 @@ class FreedomClient(object):
             for account_data in result
         ]
 
-    def get_users(self):
+    def get_users(self, params=None):
         """:obj:`list` of :obj:`User`: Fetch a list of all users that are visible/accessible.
+
+        Args:
+            params (dict): Optional query parameters.
         """
 
-        result = self.api.call("GET", "/users")
+        result = self.api.call("GET", "/users", params=params)
         if not result:
             return []
         return [User(user_data["user"], user_data, api=self.api) for user_data in result]
 
-    def get_tokens(self):
+    def get_tokens(self, params=None):
         """:obj:`list` of :obj:`dict`: Fetch a list of tokens.
+
+        Args:
+            params (dict): Optional query parameters.
         """
 
-        result = self.api.call("GET", "/accounts")
+        result = self.api.call("GET", "/accounts", params=params)
         return result
 
-    def report_issue(self, message, level, logs=None, account=None, device=None, user=None, **kwargs):
+    def report_issue(
+            self,
+            message,
+            level,
+            logs=None,
+            account=None,
+            device=None,
+            user=None,
+            params=None,
+            **kwargs):
         """Reports an issue to the API
 
         Args:
@@ -83,10 +106,11 @@ class FreedomClient(object):
             logs (list of str): List of logs describing the issue.
             account (str): The account id if present.
             device (str): The device id if present.
-            user (str): The user if prsent.
+            user (str): The user if present.
+            params (dict): Optional query parameters.
             **kwargs (dict): All the extra arguments will be sent into the body.
         """
-        
+
         if level not in ('fatal', 'warning', 'error', 'info'):
             raise Exception(
                 "Invalid level {}. Must be one of fatal, warning or error".format(level)
@@ -133,7 +157,7 @@ class FreedomClient(object):
                     "version": __version__,
                     "install_path": os.path.abspath(os.path.dirname(__file__)),
                 },
-                "system": system_data,     
+                "system": system_data,
                 "thread": {
                     "name": threading.current_thread().name,
                     "daemon": threading.current_thread().daemon
@@ -142,4 +166,4 @@ class FreedomClient(object):
         }
         data.update(kwargs)
 
-        self.api.call("PUT", "/issues", data=data)
+        self.api.call("PUT", "/issues", data=data, params=params)
