@@ -37,21 +37,26 @@ class Device(Entity):
         """
         return self._data.get("compute_architecture")
 
-    def create_token(self):
+    def create_token(self, params=None):
+        """dict: Creates a token and returns the response.
+        Args:
+            params (dict): Optional query parameters.
+        """
         response = self.api.call(
             "POST",
             "/tokens?create_secret=true",
-            data = {
-                "allowed_actions": {                
+            data={
+                "allowed_actions": {
                     "install_script": ["get"],
                     "download": ["get"],
-                    "device": ["get","put"],
+                    "device": ["get", "put"],
                     "device_data": ["put"],
                     "device_commands": ["get"],
                 },
                 "accounts": [self.account],
                 "devices": [self._id],
-            }
+            },
+            params=params,
         )
 
         if response.get("status") == "success":
@@ -256,7 +261,7 @@ class Device(Entity):
 
         return result[-1]
 
-    def get_statistics(self, utc_start=None, utc_end=None, **params):
+    def get_statistics(self, utc_start=None, utc_end=None, params=None):
         """GET statistics endpoint abstraction.
 
         Args:
@@ -264,15 +269,17 @@ class Device(Entity):
                        If null, returns the API default range (1 day).
             utc_end (float): Returns statistics until the specified timestamp (inclusive).
                        If null, returns the statistics until current hour.
-            **params: Extra parameters that could be included in the request.
+            params (dict): Extra parameters that could be included in the request.
 
         Returns:
             Dictionary with utc timestamp hourly rounded as keys, and the calculated statistics
             for each hour.
-            Note: The current hour will always return a partial result that might have a couple of 
+            Note: The current hour will always return a partial result that might have a couple of
                   minutes of delay depending on the statistic type.
         """
 
+        if params is None:
+            params = {}
         if utc_start is not None:
             params["utc_start"] = utc_start
         if utc_end is not None:
@@ -285,16 +292,18 @@ class Device(Entity):
         )
         return result
 
-    def put_statistics(self, data):
+    def put_statistics(self, data, params=None):
         """PUT statistics endpoint abstraction
 
         Args:
-            data: List with dictionaries with statistics values per hour.
+            data (list): List with dictionaries with statistics values per hour.
             More info about the object format can be found on API docs:
             https://docs.freedomrobotics.ai/reference#rest-api
+            params (dict): Extra parameters that could be included in the request.
         """
         self.api.call(
             "PUT",
             "/accounts/{}/devices/{}/statistics/".format(self.account, self._id),
-            data=data
+            data=data,
+            params=params,
         )
